@@ -4,10 +4,10 @@ from datetime import datetime
 import allure
 import pytest
 
-from lact.data import build_data
-from lact.helper import get_project_path, parse_dict, str_to_decimal, Dict
-from lact.logger import build_logger, info, error
-from lact.request import Request, build_request
+from .data import build_data
+from .helper import get_project_path, parse_dict, str_to_decimal, Dict
+from .logger import build_logger, info, error
+from .request import Request, build_request
 
 """ 私有方法，仅供本文件使用 """
 
